<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="103"/>
        <source>About this application</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="134"/>
        <source>Quit application</source>
        <translation>Zakończ program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="162"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="204"/>
        <source>Intro</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="238"/>
        <location filename="../mainwindow.ui" line="334"/>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>App Finder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="352"/>
        <source>The default KDE panel sits at the bottom on the screen and includes from left to right:

(1) Application Menu

(2) Virtual Desktop switcher

(3) Task Manager
    • Settings Manager
    • File Manager
    • Firefox browser

(4) System Tray
    • Discover
    • Yakuake drop down terminal
    • Klipper clipboard utility
    • Audio Volume Settings
    • Network Connection Settings
    • Show Status and Notifications

(5) Digital Clock

You can modify the panel by Right-Clicking on it and choosing &quot;Enter Edit Mode&quot; or &quot;Add Widgets&quot;.
Panel orientation is easily changeable in MX Tools &gt; MX Tweak.
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>
You have probably noticed that the default desktop of MX Linux has a single vertical panel on the left side of the screen.  

This may be very different to what you are used to, but it saves screen space for your applications, and it can become very natural after a short amount of time.

Panel orientation is easily changeable in MX Tools &gt; MX Tweak.

Even more options to customize your panel exist under Settings Manager &gt; Panel

Lets explore some of the key components of the panel from top to bottom:

(1) Power Button which opens a window to:
    • Log Out
    • Restart
    • Shutdown
    • Suspend

(2) Clock (Date Time)
    • Left-Click to open a calendar
    • Right-Click to change the properties

(3) Docklike Taskbar (Application Switcher)
    • Firefox browser
    • Thunar File Manager

(4) Notification Area consists of (from top to bottom)
    • Volume manager
    • USB ejector
    • Clipboard manager
    • Network manager
    • Update manager
    • Power manager

(5) Whisker Menu (Application Menu)
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>Main Menu</source>
        <translation>Menu Główne</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="465"/>
        <source>The Application Menu is a easy to use and flexible main menu.

It consists of five main areas:
(1) Favorites Quick Links
(2) Recent Applications and Files
(3) Application Categories
(4) Search bar
(5) System Quick Links

You can open the Application Menu by Left-Clicking on it or pressing the &quot;Windows&quot; key on your keyboard.

You can browse through all of your installed applications by clicking on the categories on the side.

Favorites are easy to add, reorder, and remove by Right-Clicking on any application and select “Add to Favorites”. Simply drag and drop your favorites list to arrange them.

If you’re not sure exactly where a program is listed, the search field is automatically focused when opening the menu, so you can just search by application name or general words such as &quot;browser&quot;.

You can edit the Application Menu properties by Right-Clicking on it.
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <source>Menu</source>
        <translation>Menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="514"/>
        <source>
The Whisker Menu (Applications Menu) is a easy to use and flexible main menu.

It consists of four main areas:
(1) Application Categories
(2) Individual Applications
(3) System Quick Links
(4) Search bar

You can open the Whisker Menu by Left-Clicking on it or pressing the &quot;Windows&quot; key on your keyboard.

You can browse through all of your installed applications by clicking on the categories on the side. Additionally, Whisker Menu keeps a list of the last ten Recently Used applications.

When you first open it you are shown a list of applications marked as favorites.  Favorites are easy to add and remove by Right-Clicking on any application and select “Add to Favorites”. Simply drag and drop your favorites list to arrange them.

If you’re not sure exactly where a program is listed, the search field is automatically focused when opening the menu, so you can just search by application name or general words such as &quot;browser&quot;.

You can edit the Whisker Menu properties by Right-Clicking on it.
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="542"/>
        <source>Taskbar</source>
        <translation>Pasek zadań</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="560"/>
        <source>Docklike Taskbar is a lightweight, modern, and minimalist application taskbar that sits in the panel below the clock.  It starts with Firefox browser and Thunar File Manager pinned on it.

A few things to know about Docklike Taskbar are that you can:

(1) &quot;Pin&quot; an open application by Right-Clicking and checking &quot;Pin to Dock&quot;
(2) Customize the look and feel by Right-Clicking between two icons and selecting (3) Properties

The Docklike Taskbar (3) Properties can also be accessed from the Panel Tab of MX Tweak.
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="578"/>
        <source>App Dock</source>
        <translation>Dok z aplikacjami</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="596"/>
        <source>The Quick Launch Application Dock sits on the left side of the screen and by default provides easy access to a few commonly used applications.

It consists of:
(1) MX Tools
(2) MX Fluxbox User Manual
(3) MX Fluxbox Videos
(4) MX Fluxbox Settings Manager
 
The default dock can easily be modified using MX Dockmaker; furthermore, it can be placed on auto-hide or cancelled completely using the root Menu &gt; Out of Sight.

Another dock option is available using tint2 (the software behind the panel), which makes much greater customization possible. Two tint2 dock configurations can be found using the root Menu &gt; Appearance &gt; Dock.
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="617"/>
        <source>Conky</source>
        <translation>Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="656"/>
        <source>MX Tools</source>
        <translation>MX Narzędzia</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="689"/>
        <source>MX Welcome</source>
        <translation>MX Powitanie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="707"/>
        <source>When you booted your system for the first time, you should have noticed a Welcome screen that appeared in the center of the screen that offers quick orientation and help links for new and veteran users.

You can access MX Welcome again by finding it in the main Main Application Menu or by opening MX Tools.

You can use the 'Show this dialog at start up' checkbox (as shown above) if you would like to see MX Welcome each time your system starts and uncheck it when you no longer need it.
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="722"/>
        <source>MX Fluxbox Settings</source>
        <translation>Ustawienia MX Fluxbox</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="753"/>
        <location filename="../mainwindow.ui" line="789"/>
        <location filename="../mainwindow.ui" line="828"/>
        <source>MX Tweak</source>
        <translation>MX Ulepszenia</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="771"/>
        <source>MX Tweak brings together many small customizations organized under different Tabs.

Tabs Overview:
 • Themes - select appearance elements: theme, MXFB style, icons and cursor; there is a separate app for Font
 • Fluxbox - set values for Dock, Menu, Desktop Icon, Toolbar and Thunar; Reset to defaults
 • Other - enable internal drive mount options, reset login screen, disable the All Apps menu, switch administrative account

Note: Some &quot;tweaks&quot; may not always appear, as they are desktop environment and hardware dependent.
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="807"/>
        <source>MX Tweak brings together many small but often used customizations organized under different Tabs.

Tabs Overview:
 • Panel - change the location and orientation of the panel, access the Docklike Taskbar properties
 • Theme - select a Theme Set and or individual Application, Window Manager, and Icon themes
 • Compositor - change commonly needed Window Manager Compositor options
 • Display - change Desktop scaling, monitor resolution, and brightness settings
 • Config Options - change Single-Click and Double-Click options and enable Desktop Zoom
 • Other - enable internal drive mount options, TearFree rendering, switch administrative account

Note: Some &quot;tweaks&quot; may not always appear, as they are desktop environment and hardware dependent.
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="846"/>
        <source>MX Tweak brings together some small but often used customizations organized under different Tabs.

Tabs Overview:
 • Plasma - change the location, orientation, and options of the panel
 • Other - enable internal drive mount options, TearFree rendering, switch administrative account

Note: Some &quot;tweaks&quot; may not always appear, as they are desktop environment and hardware dependent.
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="863"/>
        <source>Install Apps</source>
        <translation>Zainstaluj Aplikacje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="881"/>
        <source>MX Package Installer, often referred to simply as MXPI, allows you to search for, install, or remove packages and applications quickly, safely, and easily.

It consists of Tabs to help you install &quot;Popular Applications&quot; and any package in the MX/Debian Stable, the MX Test, Debian Backports, and Flatpak repositories.

The Popular Applications tab is organized by categories for easy searching and install.

The MX Test Repo tab is a safe and effective way to install new incoming applications that are waiting to be moved to the MX Stable repositories.

The Search function located in the upper right can help you locate applications easier.

And the Console Output tab can help you troubleshoot installation or removal issues.
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="902"/>
        <source>Discover</source>
        <translation>Odkrywca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="920"/>
        <source>Discover is also available for use to search for, install, or remove packages and applications quickly, safely, and easily.

It is a KDE native application so it also allows you to install KDE application and Plasma Add-ons such as widgets and extensions.

Discover may be considered more user friendly for new users but it is not configured for One Click installs from the MX &quot;Popular Applications&quot;, the MX Test, Debian Backports, and Flatpak repositories.  For these you should use MX Package Installer.
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="935"/>
        <location filename="../mainwindow.ui" line="971"/>
        <source>Updating</source>
        <translation>Aktualizowanie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="953"/>
        <source>MX Updater sits in the Notification Area of the panel.

The icon turns green when updates are available and notifications will also alert you that updates exist. Left-Clicking the icon opens a window showing available updates.

Right-Clicking the icon brings up a menu with many options, such as:
(1) View and Upgrade - opens a window showing availabe updates
(2) Check for Updates - checks for more updates
(3) Preferences - opens the preferences window
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="989"/>
        <source>Updates in MX KDE are handled by the Discover application.

When updates are available, the Discover icon will appear with a red dot on it in the System Tray area of the panel.

You can then Left-Click the Discover icon in the System Tray and it will open to show you available updates.

You can install all available updates or selectively choose the ones you want.

Right-Clicking the Discover icon allows you to:
    • Open Discover
    • See Updates
    • Refresh
    • Quit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1011"/>
        <source>MX Snapshot</source>
        <translation>MX Zrzut systemu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1019"/>
        <source>TextLabel</source>
        <translation>Etykieta Tekstowa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1029"/>
        <source>MX Snapshot allows you to create a bootable ISO file of your currently running MX Linux installation.

Using MX Live USB Maker, you can write the ISO file USB to use as a recovery method or to install on other systems.

Two types of Snapshot ISO files can be created:
• “Personal Snapshot” - saves almost everything, used to backup current system, and personal files
• “System Snapshot” - with apps you installed and without ones you removed, and no personal files
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1046"/>
        <source>Timeshift</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1064"/>
        <source>Timeshift is an application that provides functionality similar to the System Restore feature in Windows and the Time Machine tool in Mac OS. Timeshift protects your system by taking incremental snapshots of the file system and settings at scheduled intervals. These snapshots can be restored at a later date to undo all changes to the system.

When you open Timeshift the first time, a Setup Wizard will run allowing you to select the location snapshots are saved to, the schedule, and if you want to include personal files or not.  You can rerun the Setup Wizard or change these settings at any time.

User files such as documents, pictures and music are excluded by default. This ensures that your personal files remain unchanged when you restore your system to an earlier date.

ATTENTION!
• Pay attention to the Snapshot schedule and disk space.  You can uncheck all boxes to make only on demand snapshots.
• Timeshift is NOT a backup tool, for full system backups please use MX Snapshot or luckyBackup.
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1083"/>
        <source>System Info</source>
        <translation>Informacje o systemie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1101"/>
        <source>Quick System Info, also known as QSI, is a great and easy way to get a lot of information about your computer hardware and MX Linux installation.

The output is automatically copied to the clipboard, it can also be pasted directly into a MX Forum post complete with code tags, or pasted into a Text document for use later.

It is important to include your QSI when asking for help on the MX Forum so that the MX Community can better help you.  

QSI automatically filters potentially sensitive information such as personal identifiers, showing it instead as &quot;&lt;filter&gt;&quot;.
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1118"/>
        <source>Getting Help</source>
        <translation>Uzyskiwanie Pomocy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1148"/>
        <source>Forums</source>
        <extracomment>link to the mx forum</extracomment>
        <translation>Forum</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1271"/>
        <source>FAQ</source>
        <extracomment>frequently asked questions</extracomment>
        <translation>Często zadawane pytania</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1325"/>
        <source>Facebook</source>
        <extracomment>Facebook the social media platform</extracomment>
        <translation>Facebook</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1187"/>
        <source>Users Manual</source>
        <extracomment>the mx user manual</extracomment>
        <translation>Podręcznik użytkownika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="68"/>
        <source>&amp;Previous</source>
        <extracomment>as in go back a step</extracomment>
        <translation>&amp;Poprzedni</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="71"/>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="106"/>
        <source>A&amp;bout...</source>
        <extracomment>bring up the About... dialog</extracomment>
        <translation>&amp;O...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="137"/>
        <source>&amp;Close</source>
        <extracomment>cancel and don't do anything else</extracomment>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="159"/>
        <source>&amp;Next</source>
        <extracomment>as in go forward a step</extracomment>
        <translation>&amp;Następny</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="222"/>
        <source>Using a new Operating System for the first time can seem challenging and scary.

MX Tour is designed to introduce and orient you to many of the features and graphical tools of MX Linux.

Each of the topic areas have been separated into Tabs at the top of the dialog.

We hope you find this tour useful!</source>
        <translation>Używanie nowego systemu operacyjnego po raz pierwszy może wydawać się trudne i przerażające.

MX Tournée ma na celu wprowadzić Cię i zaznajomić z wieloma funkcjami i narzędziami graficznymi MX Linux.

Każdy z obszarów tematu został podzielony na zakładki na górze okna dialogowego.

Mamy nadzieję, że ta podróż okaże się przydatna!</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="256"/>
        <source>Let's explore some of the key components of the Tint2 panel at the bottom of the screen.

(1) Appfinder (Application Menu)

(2) Settings Manager
(3) Thunar File Manager
(4) Web Browser

(5) Notification Area consisting of:
    • Update manager
    • Network manager
    • Sound manager
    • Clipboard manager

(6) Clock (Date Time)
    • Left-Click to open a calendar, Escape (Esc) to close
    • Right-Click to set a alarm
    
(7) Power Button which opens a window to:
    • Lock • Log Out • Restart • Shutdown • Suspend

Even more options to customize your panel exist under Settings Manager &gt; Tint2 Manager, where many other templates are available.

Note that the traditional Fluxbox toolbar is also available: consult the MXFB User Manual for details.
</source>
        <translation>Przyjrzyjmy się najważniejszym komponentom znajdującego się na dole ekranu panelu Tint2.

(1) Wyszukiwarka Aplikacji (Menu Aplikacji)

(2) Menedżer ustawień
(3) Menedżer plików Thunar
(4) Przeglądarka internetowa

(5) Obszar powiadomień, zawierający:
    • Menedżer aktualizacji
    • Menedżer sieci
    • Menedżer dźwięku
    • Menedżer schowka

(6) Zegar (czas data)
    • Lewe kliknięcie otwiera kalendarz, Escape (Esc) - zamyka
    • Prawe kliknięcie ustawia budzik
    
(7) Wyłącznik który otwiera okno umożliwiające
    • Zablokowanie ekranu • Wylogowanie • Restart • Wyłączenie • Wstrzymanie

Więcej opcji umożliwiających konfigurację panelu znajdziesz pod: Menedżer ustawień &gt; Menedżer Tint2, gdzie dostępne jest wiele różnych szablonów.

Zauważ, że dostępny jest także tradycyjny pasek narzędzi Fluxbox - szczegóły są omówione w podręczniku użytkownika MXFB.
</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>There are three very different application finders in MXFB, providing the user with choice of which to retain and use.

1. The Applications Menu (&quot;Rofi Appfinder&quot;) is opened by Left-Clicking on the MX logo in the Panel. It consists of three main areas:

(1) Search Bar at the top
(2) Tabs on the left side for Applications, Categories and Help 
(3) Tab details on the right side

The search field is automatically focused when opening the menu, so you can just search by application name or general words such as &quot;browser&quot;. To open an application, Click on your selection or press Return. You can edit the menu behavior and appearance using the contents of the Help tab.

(Appfinder is built using &quot;rofi,&quot; a very flexible and fast app with many applications that can be launched by pressing the logo or super key. Its settings are available in a separate app &quot;Rofi Manager&quot; that includes a large selection of possible templates.)

2. A second applications menu (the &quot;rootMenu&quot;) is revealed by a right-click on the desktop and is a legacy of the original Fluxbox. It is a static and very rapid menu of common applications, settings and actions that can easily be edited by the user. 

3. Included at the top of that rootMenu, finally, is a third application finder called &quot;All Apps.&quot; It is similar in structure and behavior to a typical Debian menu, and updates automatically. 

</source>
        <translation>Dostępne są trzy zupełnie różne wyszukiwarki aplikacji w MXFB, co umożliwia użytkownikowi wybór, którą z nich chce zachować i używać.

1. Menu Aplikacji  (&quot;Wyszukiwarka aplikacji Rofi&quot;) otwiera się przez kliknięcie lewego przycisku myszy na logo MX na panelu. Zawiera ono trzy obszary:

(1) Pasek wyszukiwania na górze
(2) Zakładki po lewej stronie, odpowiednio: Aplikacje, Kategorie i Pomoc 
(3) Zawartość zakładki po prawej stronie

Pole wyszukiwania jest wybrane automatycznie podczas otwierania menu, więc możesz po prostu wyszukiwać według nazwy aplikacji lub ogólnych słów, takich jak „przeglądarka”. Aby otworzyć aplikację, kliknij na wybór lub naciśnij Enter. Możesz edytować zachowanie i wygląd menu za pomocą polecenia w zakładce pomocy.

(Wyszukiwarka aplikacji jest zbudowana przy użyciu „ROFI”, bardzo elastycznego i szybkiego programu umożliwiającego dostęp do wielu aplikacji po kliknięciu w ikonę logo lub naciśnięciu klawisza Super. Jego ustawienia są dostępne w osobnej aplikacji „Menedżer ROFI”, która zawiera duży wybór możliwych do zastosowania szablonów.)

2. Drugie menu aplikacji („rootMenu”) uruchamia się przez kliknięcie prawym przyciskiem myszy na pulpicie i stanowi integralną część menedżera okien Fluxbox. Jest to statyczne i bardzo szybkie menu zawierające podstawowe aplikacje, ustawienia i czynności. Zawartość tego menu może być w prosty sposób edytowana przez użytkownika. 

3. U góry wspomnianego rootMenu znajduje się wreszcie trzecia wyszukiwarka aplikacji o nazwie „Wszystkie aplikacje”. Ma podobną strukturę i zachowanie do typowego menu Debiana i aktualizuje się automatycznie. 

</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="635"/>
        <source>You may have wondered about the Clock in the upper right corner of your screen, it is a Conky.

Conky is a light-weight system monitor that can display any kind of information on your desktop, either as text, or using simple progress bars and graph widgets, with different fonts and colors.

It can display the status of the CPU, memory, disk storage, temperatures, network interfaces, battery power, e-mail inboxes, many popular music players, weather updates, news feeds, and much more.

MX Linux comes with many different Conkies to choose from or edit.

MX Linux comes with two tools for Conky:
• Conky Toggle - to easily turn Conky off or on
• MX Conky - utility for managing, editing and viewing Conky configuration files
</source>
        <translation>Zastanawiasz się pewnie, czym jest ten zegar w prawym górnym rogu Twojego ekranu. To jest Conky.

Conky to lekki monitor systemu, który pozwala wyświetlać dowolne informacje na Twoim pulpicie, albo w formie tekstu, albo za pomocą prostych pasków postępu, czy też graficznych wykresów, z wykorzystaniem różnych czcionek i kolorów.

Może wyświetlać status procesora, pamięci, interfejsów sieciowych, ilość miejsca na dysku, temperaturę podzespołów, poziom baterii, skrzynki odbiorcze e-mail, wiele popularnych odtwarzaczy muzyki, aktualną pogodę, kanały informacyjne i wiele więcej.

MX Linux umożliwia Ci wybór spośród wielu gotowych ustawień Conky oraz ich dowolne edytowanie.

MX Linux posiada dwa własne narzędzia dla Conky:
• Przełącznik Conky - aby w prosty sposób włączać i wyłączać Conky
• MX Conky - narzędzie umożliwiające zarządzanie, edytowanie i pogląd plików konfiguracyjnych Conky 
</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="674"/>
        <source>Many applications have been developed specifically for MX Linux, adapted or brought over from antiX Linux, or adapted from outside sources to save you effort with important tasks often involving unintuitive steps.

The MX Tools dashboard (shown above), centralizes and organizes these tools for easy access and use.

Let's explore some MX Tools to help you setup and use your computer.
</source>
        <translation>Wiele aplikacji zostało opracowanych specjalnie dla MX Linux, dostosowanych albo przeniesionych z Antix Linux, lub z zewnętrznych źródeł, aby ułatwić wykonywanie ważnych zadań i  dostosowywanie systemu, które normalnie  wymagają podejmowania skomplikowanych i mało intuicyjnych kroków.

Pulpit nawigacyjny MX Narzędzia (pokazany powyżej), skupia w sobie i organizuje te narzędzia w celu ułatwienia dostępu do nich i ich wygodnego użytkowania.

Poznajmy kilka narzędzi MX, które pomogą Ci w konfiguracji i użytkowaniu Twojego komputera.
</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="740"/>
        <source>MXFB Settings Manager is your one-stop shop for tools to save you effort with important tasks and customizations using settings often involving unintuitive steps.

MXFB Settings Manager includes many applications have been developed or adapted specifically for MX Linux Fluxbox.
</source>
        <translation>Menedżer ustawień MXFB jest tym miejscem, w którym znajdziesz narzędzia ułatwiające wykonywanie ważnych zadań i dostosowywanie systemu — także w obszarach, które normalnie wymagają skomplikowanych lub mało intuicyjnych kroków.

Menedżer ustawień MXFB obejmuje liczne aplikacje, które zostały opracowane lub dostosowane specjalnie dla MX Linux FluxBox.
</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1299"/>
        <source>Wiki</source>
        <extracomment>link to the mx wiki</extracomment>
        <translation>Wiki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1245"/>
        <source>Videos</source>
        <extracomment>link to videos page of mx website</extracomment>
        <translation>Wideo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1213"/>
        <source>Reddit</source>
        <extracomment>link to the mx sub reddit</extracomment>
        <translation>Reddit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1171"/>
        <source>Below are some available resources to get help</source>
        <extracomment>generic statement about resources offered</extracomment>
        <translation>Poniżej znajdują się dostępne zasoby, umożliwiające uzyskanie pomocy</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="103"/>
        <location filename="../mainwindow.cpp" line="130"/>
        <source>MX Tour</source>
        <translation>MX Tournée</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="129"/>
        <source>About MX Tour</source>
        <translation>O MX Tournée</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="130"/>
        <source>Version: </source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="131"/>
        <source>Explore and learn about MX Linux</source>
        <translation>Odkrywaj i poznawaj MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="134"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Prawa autorskie © MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="135"/>
        <source>%1 License</source>
        <translation>%1 Licencja</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="61"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="62"/>
        <location filename="../about.cpp" line="72"/>
        <source>Changelog</source>
        <translation>Dziennik zmian</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="85"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>This tool displays a tabbed Tour screen.</source>
        <translation>To narzędzie wyświetla ekran Tournée w zakładkach.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>You must run this program as normal user.</source>
        <translation>Musisz uruchomić ten program jako zwykły użytkownik.</translation>
    </message>
</context>
</TS>